@@ -4,6 +4,9 @@
 #' @param shardby the shardkeys
 #' @param outdir the output directory
 #' @param overwrite overwrite the output directory
+#' @param shardby_function splitting of chunks: "hash" for hash function or "sort" for semi-sorted chunks
+#' @param sort_splits for the "sort" shardby function, a dataframe with the split values.
+#' @param desc_vars for the "sort" shardby function, the variables to sort descending.
 #' @export
 #' @examples
 #' # create a disk.frame with 2 chunks in tempdir()
@@ -19,7 +22,7 @@
 #' # clean up cars.df
 #' delete(cars.df)
 #' delete(cars2.df)
-rechunk <- function(df, nchunks, outdir = attr(df, "path"), shardby = NULL, overwrite = TRUE) {
+rechunk <- function(df, nchunks, outdir = attr(df, "path"), shardby = NULL, overwrite = TRUE, shardby_function="hash", sort_splits=NULL, desc_vars=NULL) {
   
   # we need to force the chunks to be computed first as it's common to make nchunks a multiple of chunks(df)
   # but if we do it too late then the folder could be empty
@@ -75,7 +78,7 @@ rechunk <- function(df, nchunks, outdir = attr(df, "path"), shardby = NULL, over
 
 
   if(user_had_set_shard_by) {
-    return(hard_group_by(df, shardby, nchunks = nchunks, outdir = outdir, overwrite = TRUE))
+    return(hard_group_by(df, shardby, nchunks = nchunks, outdir = outdir, overwrite = TRUE, shardby_function=shardby_function, sort_splits=sort_splits, desc_vars=desc_vars))
   } else if (identical(shardby, "") | is.null(shardby)) {
     # if no existing shardby 
     nr = nrow(df)
